@@ -18,11 +18,11 @@ Museum::Rijksmuseum::Object - Access the Rijksmuseum object metadata API
 
 =head1 VERSION
 
-Version 0.01
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 
 =head1 SYNOPSIS
@@ -160,9 +160,8 @@ sub _fetch_url {
     my $req = HTTP::Request->new( GET => $url );
 
     my $res = $ua->request($req);
-
     if ( $res->is_success ) {
-        my $json = JSON::MaybeXS->new( utf8 => 1 );
+        my $json = JSON::MaybeXS->new();
         return $json->decode( $res->content );
     } else {
         return { error => $res->status_line };
